gdb: The GNU Project debugger
=============================

Description
-----------

GDB, the GNU Project debugger, allows you to see what is going on
"inside" another program while it executes -- or what another program
was doing at the moment it crashed.

License
-------

GPL v3+


Upstream Contact
----------------

http://www.gnu.org/software/gdb/
